%% Extracts HYCOM initial conditions for GULF OF MEXICO
clear all;
close all;
clc;

%% My model paths.
fpath   = '/net/wave3/ganeshgopal/NEWDATA/FROM_WAVE5_DATA_MOVED_DATA_GANESH/GOM_OI_24DEG/FORCINGS/';
hycompath = '/net/wave3/ganeshgopal/NEW_DATA/FROM_WAVE5_DATA_MOVED_DATA/GOM_OI_24DEG/hycom_15d/';

eval(['load ' fpath 'FMT.mat']);
eval(['load ' fpath 'GRID.mat']);

%% X = 101 (LON), Y = 98(LAT), Z = 33(DEPTH), 121(TIME) 
nx1 =  101; ny1 = 98; nz1 = 33; nt1 = 121;
lon_hycom = rdslice([hycompath 'lon_hycom.bin'],[nx1 1],1,fmt,Ieee);
lat_hycom = rdslice([hycompath 'lat_hycom.bin'],[ny1 1],1,fmt,Ieee);
z_hycom = rdslice([hycompath 'depth_hycom.bin'],[nz1 1],1,fmt,Ieee);
time_hycom = rdslice([hycompath 'time_hycom.bin'],[1 1],1,fmt,Ieee);%% for IC first time
uhycom = rdslice([hycompath 'uhycom.bin'],[nx1 ny1 nz1],1,fmt,Ieee);%% for IC first time
vhycom = rdslice([hycompath 'vhycom.bin'],[nx1 ny1 nz1],1,fmt,Ieee);%% for IC first time
thycom = rdslice([hycompath 'thycom.bin'],[nx1 ny1 nz1],1,fmt,Ieee);%% for IC first time
shycom = rdslice([hycompath 'shycom.bin'],[nx1 ny1 nz1],1,fmt,Ieee);%% for IC first time

date = ['2004_2008_GOM_OI_' datestr(time_hycom(1),3) datestr(time_hycom(1),7)];


%% Extract HYCOM fields at this time

[Tm,xc,yc,zc] = exinthycomic(fpath,'T',thycom,time_hycom,lon_hycom,lat_hycom,z_hycom,xc,yc,xf,yf,zc,fmt,Ieee);
[Sm,xc,yc,zc] = exinthycomic(fpath,'S',shycom,time_hycom,lon_hycom,lat_hycom,z_hycom,xc,yc,xf,yf,zc,fmt,Ieee);
[Um,xc,yc,zc] = exinthycomic(fpath,'U',uhycom,time_hycom,lon_hycom,lat_hycom,z_hycom,xc,yc,xf,yf,zc,fmt,Ieee);
[Vm,xc,yc,zc] = exinthycomic(fpath,'V',vhycom,time_hycom,lon_hycom,lat_hycom,z_hycom,xc,yc,xf,yf,zc,fmt,Ieee);

T = reshape(Tm,nxc,nyc,nzc);
S = reshape(Sm,nxc,nyc,nzc);
U = reshape(Um,nxc,nyc,nzc);
V = reshape(Vm,nxc,nyc,nzc);

%% Save outputs
wrslice([fpath 'hycom_T_' date '.bin'],T,1,fmt,Ieee);
wrslice([fpath 'hycom_S_' date '.bin'],S,1,fmt,Ieee);
wrslice([fpath 'hycom_U_' date '.bin'],U,1,fmt,Ieee);
wrslice([fpath 'hycom_V_' date '.bin'],V,1,fmt,Ieee);

%% Check if data are available over all model grid
check3dmask(fpath,['hycom_T_' date '.bin'],1);
check3dmask(fpath,['hycom_S_' date '.bin'],1);
check3dmask(fpath,['hycom_U_' date '.bin'],1);
check3dmask(fpath,['hycom_V_' date '.bin'],1);